@@ -1,7 +1,7 @@
 package File::Serialize::Serializer;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Role for defining File::Serialize serializers
-$File::Serialize::Serializer::VERSION = '1.1.1';
+$File::Serialize::Serializer::VERSION = '1.2.0';
 
 use strict;
 use warnings;
@@ -10,8 +10,7 @@ use List::MoreUtils qw/ any all /;
 use Module::Info;
 use Module::Runtime qw/ use_module /;
 
-use Moo::Role;
-use MooX::ClassAttribute;
+use Role::Tiny;
 
 requires 'extensions';  # first extension is the canonical one
 
@@ -83,7 +82,7 @@ File::Serialize::Serializer - Role for defining File::Serialize serializers
 
 =head1 VERSION
 
-version 1.1.1
+version 1.2.0
 
 =head1 SYNOPSIS
 
@@ -178,7 +177,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Yanick Champoux.
+This software is copyright (c) 2017, 2016, 2015 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
